@@ -9,21 +9,21 @@
 // or else upgrading old project file will not work
 // reliably.
 // TODO QGIS 4: remove in favor of _QGIS_VERSION
-#define VERSION "3.38.3-Grenoble"
-#define _QGIS_VERSION "3.38.3-Grenoble"
+#define VERSION "3.40.3-Bratislava"
+#define _QGIS_VERSION "3.40.3-Bratislava"
 
 //used in vim src/core/qgis.cpp
 //The way below should work but it resolves to a number like 0110 which the compiler treats as octal I think
 //because debuggin it out shows the decimal number 72 which results in incorrect version status.
 //As a short term fix I (Tim) am defining the version in top level cmake. It would be good to
 //reinstate this more generic approach below at some point though
-//#define VERSION_INT 3383
+//#define VERSION_INT 3403
 // TODO QGIS 4: Remove in favor of _QGIS_VERSION_INT
-#define VERSION_INT 33803
-#define _QGIS_VERSION_INT 33803
-#define ABISYM(x) x ## 33803
+#define VERSION_INT 34003
+#define _QGIS_VERSION_INT 34003
+#define ABISYM(x) x ## 34003
 //used in main.cpp and anywhere else where the release name is needed
-#define RELEASE_NAME "Grenoble"
+#define RELEASE_NAME "Bratislava"
 
 #define QGIS_PLUGIN_SUBDIR "lib/qgis/plugins"
 #define QGIS_DATA_SUBDIR "share/qgis"
@@ -42,14 +42,14 @@
 #define QGIS_MACAPP_BUNDLE 
 #endif
 
-#define PYTHON_VERSION "3.12.6"
+#define PYTHON_VERSION "3.13.1"
 #define PYTHON_VERSION_MAJOR "3"
-#define PYTHON_VERSION_MINOR "12"
-#define PYTHON_VERSION_PATCH "6"
+#define PYTHON_VERSION_MINOR "13"
+#define PYTHON_VERSION_PATCH "1"
 
 #define PROJ_VERSION_MAJOR 9
 #define PROJ_VERSION_MINOR 5
-#define PROJ_VERSION_PATCH 0
+#define PROJ_VERSION_PATCH 1
 
 /* #undef USING_NMAKE */
 
@@ -103,12 +103,12 @@
 #define HAVE_COPC
 
 #define HAVE_PDAL_QGIS
-#define PDAL_VERSION "2.8.0"
+#define PDAL_VERSION "2.8.3"
 #define PDAL_VERSION_MAJOR_INT 2
 #define PDAL_VERSION_MINOR_INT 8
 #define PDAL_VERSION_MAJOR "2"
 #define PDAL_VERSION_MINOR "8"
-#define PDAL_VERSION_MICRO "0"
+#define PDAL_VERSION_MICRO "3"
 
 #define HAVE_DRACO
 
